_`umbra.ui.visualAccelerators`
==============================

.. automodule:: umbra.ui.visualAccelerators

Module Attributes
-----------------

.. attribute:: umbra.ui.visualAccelerators.LOGGER

Functions
---------

.. autofunction:: highlightCurrentLine

.. autofunction:: highlightOccurences

.. autofunction:: highlightMatchingSymbolsPairs

